@@ -185,6 +185,41 @@ class ActivityService:
         """
         return self.__client.call("eleme.activity.coupon.updateCouponStatus", {"criteria": criteria, "type": type})
 
+    def create_activity_template_v_2(self, activity_template):
+        """
+        创建券模板
+        :param activityTemplate:创建券模板对象
+        """
+        return self.__client.call("eleme.activity.coupon.createActivityTemplateV2", {"activityTemplate": activity_template})
+
+    def modify_activity_template_v_2(self, update_model):
+        """
+        修改券模板
+        :param updateModel:修改券模板对象
+        """
+        return self.__client.call("eleme.activity.coupon.modifyActivityTemplateV2", {"updateModel": update_model})
+
+    def invalid_activity_template_v_2(self, invalid_model):
+        """
+        作废券模板
+        :param invalidModel:作废券模板对象
+        """
+        return self.__client.call("eleme.activity.coupon.invalidActivityTemplateV2", {"invalidModel": invalid_model})
+
+    def query_by_template_id_v_2(self, query_model):
+        """
+        查询券模板
+        :param queryModel:查询券模板对象
+        """
+        return self.__client.call("eleme.activity.coupon.queryByTemplateIdV2", {"queryModel": query_model})
+
+    def present_coupon_with_template_id_v_2(self, present_with_template_model):
+        """
+        根据券模板发券
+        :param presentWithTemplateModel:发券对象
+        """
+        return self.__client.call("eleme.activity.coupon.presentCouponWithTemplateIdV2", {"presentWithTemplateModel": present_with_template_model})
+
     def query_order_subsidy(self, order_id):
         """
         查询订单内营销相关数据
@@ -192,6 +227,55 @@ class ActivityService:
         """
         return self.__client.call("eleme.activity.marketing.queryOrderSubsidy", {"orderId": order_id})
 
+    def create_campaign_dy_channel(self, request):
+        """
+        抖音创建招商活动后调用，创建e侧抖音频道
+        :param request:创建e侧抖音频道
+        """
+        return self.__client.call("eleme.activity.dy.createCampaignDyChannel", {"request": request})
+
+    def audit_status_call_back(self, request):
+        """
+        抖音审核状态回调
+        :param request:抖音审核状态回调
+        """
+        return self.__client.call("eleme.activity.dy.auditStatusCallBack", {"request": request})
+
+    def query_ele_apply_status(self, request):
+        """
+        抖音查询e侧报名单状态，用于核对状态一致性
+        :param request:查询e侧报名单状态
+        """
+        return self.__client.call("eleme.activity.dy.queryEleApplyStatus", {"request": request})
+
+    def offline_sku_apply(self, request):
+        """
+        抖音侧商品退出报名时调用，e侧商品退出报名
+        :param request:商品退出报名
+        """
+        return self.__client.call("eleme.activity.dy.offlineSkuApply", {"request": request})
+
+    def create_coupon_activity(self, request):
+        """
+        抖音侧创建券活动时调用
+        :param request:抖音创建券活动
+        """
+        return self.__client.call("eleme.activity.dy.createCouponActivity", {"request": request})
+
+    def modify_coupon_activity(self, request):
+        """
+        抖音侧修改券活动时调用
+        :param request:抖音创建券活动
+        """
+        return self.__client.call("eleme.activity.dy.modifyCouponActivity", {"request": request})
+
+    def query_dy_coupon_activity(self, request):
+        """
+        根据dy券活动id查询券活动信息
+        :param request:抖音查询券活动信息
+        """
+        return self.__client.call("eleme.activity.dy.queryDyCouponActivity", {"request": request})
+
     def create_and_participate_chain_price_activity(self, activity, chain_id, shop_apply_info):
         """
         创建并绑定连锁店特价活动
