@@ -36,3 +36,17 @@ class MessageService:
         """
         return self.__client.call("eleme.message.testInterface", {})
 
+    def disable_push_config(self, disable_push_request):
+        """
+        禁止推送消息设置
+        :param disablePushRequest:禁止推送消息设置
+        """
+        return self.__client.call("eleme.message.disablePushConfig", {"disablePushRequest": disable_push_request})
+
+    def query_disable_push(self, disable_push_query):
+        """
+        查询已经设置禁用推送的设置信息
+        :param disablePushQuery:查询已经设置禁用推送的设置信息
+        """
+        return self.__client.call("eleme.message.queryDisablePush", {"disablePushQuery": disable_push_query})
+
