@@ -16,6 +16,22 @@ class ShopService:
         """
         return self.__client.call("eleme.shop.getShop", {"shopId": shop_id})
 
+    def dy_call_back_for_ele(self, ele__dto):
+        """
+        抖音回调接口
+        :param ele_dto:回调对象
+        """
+        return self.__client.call("eleme.shop.dyCallBackForEle", {"ele_dto": ele__dto})
+
+    def dy_un_bind_shop_for_ele(self, account_id, merchant_id, version):
+        """
+        抖音解绑回调接口
+        :param accountId:抖音总户ID
+        :param merchantId:抖音门店户ID
+        :param version:版本号
+        """
+        return self.__client.call("eleme.shop.dyUnBindShopForEle", {"accountId": account_id, "merchantId": merchant_id, "version": version})
+
     def update_shop(self, shop_id, properties):
         """
         更新店铺信息
@@ -134,6 +150,28 @@ class ShopService:
         """
         return self.__client.call("eleme.shop.getShopLicense", {"shopId": shop_id})
 
+    def get_wss_address(self, query_long_line_address_d_t_o):
+        """
+        查询长链地址
+        :param queryLongLineAddressDTO:查询长链地址表单
+        """
+        return self.__client.call("eleme.shop.im.getWssAddress", {"queryLongLineAddressDTO": query_long_line_address_d_t_o})
+
+    def get_i_m_status(self, shop_id):
+        """
+        查询店铺IM状态
+        :param shopId:店铺ID
+        """
+        return self.__client.call("eleme.shop.im.getIMStatus", {"shopId": shop_id})
+
+    def update_i_m_status(self, shop_id, status):
+        """
+        更新店铺IM开关状态
+        :param shopId:店铺ID
+        :param status:IM开关状态（0：关闭 1：开启）
+        """
+        return self.__client.call("eleme.shop.im.updateIMStatus", {"shopId": shop_id, "status": status})
+
     def submit_open_store_message_audit(self, open_store_message):
         """
         提交开店申请接口
@@ -183,3 +221,10 @@ class ShopService:
         """
         return self.__client.call("eleme.shop.setup.uploadImageWithRemoteUrl", {"url": url})
 
+    def set_video_status(self, video_device_d_t_o):
+        """
+        第三方服务商传递摄像头状态变更消息
+        :param videoDeviceDTO:设备状态信息
+        """
+        return self.__client.call("eleme.shop.video.setVideoStatus", {"videoDeviceDTO": video_device_d_t_o})
+
