@@ -11,6 +11,7 @@ except ImportError:
     from urllib.parse import urlparse, urlencode
 
 from sdk.exception.unauthorized_exception import UnauthorizedException
+from sdk.exception.identity_exception import IdentityException
 
 import sys
 if sys.version < '3':
@@ -25,12 +26,13 @@ class OAuthClient:
         self.callback_url = config.get_callback_url()
         self.request_url = config.get_access_token_url()
         self.authorize_url = config.get_authorize_url()
+        self.openId_request_url = config.get_openId_url()   # openId request
         self.log = config.get_log()
 
     # 根据key和secret获取token（客户端授权模式）
     def get_token_in_client_credentials(self):
         data = {"grant_type": "client_credentials"}
-        return self.do_request(data)
+        return self.do_request(data, self.request_url, "oauth")
 
     # 构造授权URL（授权码模式）
     def get_auth_url(self, state, scope):
@@ -49,7 +51,7 @@ class OAuthClient:
                 "redirect_uri": callback_url,
                 "client_id": self.client_id}
 
-        return self.do_request(data)
+        return self.do_request(data, self.request_url, "oauth")
 
     # 根据refresh_token刷新获取token（授权码模式）
     def get_token_by_refresh_token(self, refresh_token, scope):
@@ -57,21 +59,35 @@ class OAuthClient:
                 "refresh_token": refresh_token,
                 "scope": scope}
 
-        return self.do_request(data)
+        return self.do_request(data, self.request_url, "oauth")
 
-    def do_request(self, body):
+    
+    # 根据code 获取openId
+    def get_openId_by_code(self, code):
+        callback_url = self.callback_url
+        data = {"grant_type": "authorization_code",
+                "code": code,
+                "redirect_uri": callback_url,
+                "client_id": self.client_id}
+        
+        return self.do_request(data, self.openId_request_url, "openId")
+
+    def do_request(self, body, request, sign):
         data = urlencode(body).encode("ascii")
         header = self.get_headers()
-        self.log.info(u"oauth client request body: {},headers:{}".format(data, header))
-        req = Request(self.request_url, data, header)
+        self.log.info(sign + u"oauth client request body: {},headers:{}".format(data, header))
+        req = Request(request, data, header)
         result = None
         try:
             response = urlopen(req)
             result = response.read()
         except Exception as e:
-            self.log.error("oauth client request error :" + e.read().decode())
-            raise UnauthorizedException(e.read().decode())
-        self.log.info("oauth client response :"+result.decode())
+            self.log.error(sign + " client request error :" + e.read().decode())
+            if sign is "oauth":
+                raise UnauthorizedException(e.read().decode())
+            else:
+                raise IdentityException(e.read().decode())
+        self.log.info(sign + " client response :" + result.decode())
         return result.decode()
 
     def get_headers(self):
